# AUTOGENERATED BY NBDEV! DO NOT EDIT!

__all__ = ["index", "modules", "custom_doc_links", "git_url"]

index = {"PathOrStr": "utils.ipynb",
         "ListOfPaths": "utils.ipynb",
         "ListOfStrings": "utils.ipynb",
         "ls": "utils.ipynb",
         "Path.ls": "utils.ipynb",
         "Path.listdirs": "utils.ipynb",
         "get_files": "utils.ipynb",
         "get_image_files": "utils.ipynb",
         "image_extensions": "utils.ipynb",
         "video_extensions": "utils.ipynb",
         "flatten": "utils.ipynb",
         "uniqueify": "utils.ipynb"}

modules = ["utils.py"]

doc_url = "https://rsomani95.github.io/nbdev_template/"

git_url = "https://github.com/rsomani95/nbdev_template/tree/master/"

def custom_doc_links(name): return None
